@@ -1,6 +1,3 @@
-/* krb5-types.h -- this file was generated for sparc64-unknown-openbsd5.9 by
-                   $Id$ */
-
 #ifndef __krb5_types_h__
 #define __krb5_types_h__
 
@@ -15,8 +12,18 @@ typedef ssize_t krb5_ssize_t;
 
 typedef int krb5_socket_t;
 
+#if !defined(__has_extension)
+#define __has_extension(x) 0
+#endif
+
+#ifndef KRB5TYPES_REQUIRE_GNUC
+#define KRB5TYPES_REQUIRE_GNUC(m,n,p) \
+    (((__GNUC__ * 10000) + (__GNUC_MINOR__ * 100) + __GNUC_PATCHLEVEL__) >= \
+     (((m) * 10000) + ((n) * 100) + (p)))
+#endif
+
 #ifndef HEIMDAL_DEPRECATED
-#if defined(__GNUC__) && ((__GNUC__ > 3) || ((__GNUC__ == 3) && (__GNUC_MINOR__ >= 1 )))
+#if __has_extension(deprecated) || KRB5TYPES_REQUIRE_GNUC(3,1,0)
 #define HEIMDAL_DEPRECATED __attribute__((deprecated))
 #elif defined(_MSC_VER) && (_MSC_VER>1200)
 #define HEIMDAL_DEPRECATED __declspec(deprecated)
@@ -24,25 +31,37 @@ typedef int krb5_socket_t;
 #define HEIMDAL_DEPRECATED
 #endif
 #endif
+
 #ifndef HEIMDAL_PRINTF_ATTRIBUTE
-#if defined(__GNUC__) && ((__GNUC__ > 3) || ((__GNUC__ == 3) && (__GNUC_MINOR__ >= 1 )))
+#if __has_extension(format) || KRB5TYPES_REQUIRE_GNUC(3,1,0)
 #define HEIMDAL_PRINTF_ATTRIBUTE(x) __attribute__((format x))
 #else
 #define HEIMDAL_PRINTF_ATTRIBUTE(x)
 #endif
 #endif
+
 #ifndef HEIMDAL_NORETURN_ATTRIBUTE
-#if defined(__GNUC__) && ((__GNUC__ > 3) || ((__GNUC__ == 3) && (__GNUC_MINOR__ >= 1 )))
+#if __has_extension(noreturn) || KRB5TYPES_REQUIRE_GNUC(3,1,0)
 #define HEIMDAL_NORETURN_ATTRIBUTE __attribute__((noreturn))
 #else
 #define HEIMDAL_NORETURN_ATTRIBUTE
 #endif
 #endif
+
 #ifndef HEIMDAL_UNUSED_ATTRIBUTE
-#if defined(__GNUC__) && ((__GNUC__ > 3) || ((__GNUC__ == 3) && (__GNUC_MINOR__ >= 1 )))
+#if __has_extension(unused) || KRB5TYPES_REQUIRE_GNUC(3,1,0)
 #define HEIMDAL_UNUSED_ATTRIBUTE __attribute__((unused))
 #else
 #define HEIMDAL_UNUSED_ATTRIBUTE
 #endif
 #endif
+
+#ifndef HEIMDAL_WARN_UNUSED_RESULT_ATTRIBUTE
+#if __has_extension(warn_unused_result) || KRB5TYPES_REQUIRE_GNUC(3,3,0)
+#define HEIMDAL_WARN_UNUSED_RESULT_ATTRIBUTE __attribute__((warn_unused_result))
+#else
+#define HEIMDAL_WARN_UNUSED_RESULT_ATTRIBUTE
+#endif
+#endif
+
 #endif /* __krb5_types_h__ */
